==> fuel-ui-0.4.1-3.tgz: package/esm/components/Accordion/Accordion.js <==
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, Input, NgModule, ContentChildren, QueryList } from '@angular/core';
import { CommonModule } from "@angular/common";
import { AccordionItem } from './accordionItem';
import { Collapse } from '../../animations/Collapse/Collapse';
export let Accordion = class Accordion {
    constructor() {
        this.closeOthers = true;
        this.duration = 250;
        this.itemEvents = [];
    }
    ngAfterContentInit() {
        this.items.changes.subscribe(i => this.registerItems());
        this.registerItems();
    }
    registerItems() {
        for (let event of this.itemEvents)
            event.unsubscribe();
        for (let item of this.items.toArray()) {
            item.openChange.subscribe(() => {
                this.closeOtherItems(item);
            });
        }
    }
    closeOtherItems(openItem) {
        if (!this.closeOthers)
            return;
        this.items.forEach((item) => {
            if (item !== openItem) {
                item.open = false;
            }
        });
    }
};
__decorate([
    Input(), 
    __metadata('design:type', Boolean)
], Accordion.prototype, "closeOthers", void 0);
__decorate([
    Input(), 
    __metadata('design:type', Number)
], Accordion.prototype, "duration", void 0);
__decorate([
    ContentChildren(AccordionItem), 
    __metadata('design:type', QueryList)
], Accordion.prototype, "items", void 0);
Accordion = __decorate([
    Component({
        selector: 'accordion',
        template: `<ng-content></ng-content>`,
        animations: [Collapse(350)]
    }), 
    __metadata('design:paramtypes', [])
], Accordion);
const accordionComponents = [
    Accordion,
    AccordionItem
];
export let FuiAccordionModule = class FuiAccordionModule {
};
FuiAccordionModule = __decorate([
    NgModule({
        imports: [CommonModule],
        declarations: accordionComponents,
        exports: accordionComponents
    }), 
    __metadata('design:paramtypes', [])
], FuiAccordionModule);

==> fuel-ui-0.4.1-5.tgz: package/esm/components/Accordion/Accordion.js <==
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, Input, NgModule, ContentChildren, QueryList } from '@angular/core';
import { CommonModule } from "@angular/common";
import { AccordionItem } from './AccordionItem';
import { Collapse } from '../../animations/Collapse/Collapse';
export let Accordion = class Accordion {
    constructor() {
        this.closeOthers = true;
        this.duration = 250;
        this.itemEvents = [];
    }
    ngAfterContentInit() {
        this.items.changes.subscribe(i => this.registerItems());
        this.registerItems();
    }
    registerItems() {
        for (let event of this.itemEvents)
            event.unsubscribe();
        for (let item of this.items.toArray()) {
            item.openChange.subscribe(() => {
                this.closeOtherItems(item);
            });
        }
    }
    closeOtherItems(openItem) {
        if (!this.closeOthers)
            return;
        this.items.forEach((item) => {
            if (item !== openItem) {
                item.open = false;
            }
        });
    }
};
__decorate([
    Input(), 
    __metadata('design:type', Boolean)
], Accordion.prototype, "closeOthers", void 0);
__decorate([
    Input(), 
    __metadata('design:type', Number)
], Accordion.prototype, "duration", void 0);
__decorate([
    ContentChildren(AccordionItem), 
    __metadata('design:type', QueryList)
], Accordion.prototype, "items", void 0);
Accordion = __decorate([
    Component({
        selector: 'accordion',
        template: `<ng-content></ng-content>`,
        animations: [Collapse(350)]
    }), 
    __metadata('design:paramtypes', [])
], Accordion);
const accordionComponents = [
    Accordion,
    AccordionItem
];
export let FuiAccordionModule = class FuiAccordionModule {
};
FuiAccordionModule = __decorate([
    NgModule({
        imports: [CommonModule],
        declarations: accordionComponents,
        exports: accordionComponents
    }), 
    __metadata('design:paramtypes', [])
], FuiAccordionModule);
